"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.libName = exports.initialiseFfi = void 0;
var ffi = require("ffi-napi");
var path = require("path");
var PLATFORM_LOOKUP = {
    linux: 'linux',
    darwin: 'osx',
    win32: 'windows',
};
var ARCH_LOOKUP = { x64: 'x86_64' };
var EXTENSION_LOOKUP = {
    'osx-x86_64': 'dylib',
    'linux-x86_64': 'so',
    'windows-x86_64': 'dll',
};
var initialiseFfi = function (filename, description) {
    return ffi.Library(path.resolve(__dirname, '..', '..', '..', 'ffi', filename), description);
};
exports.initialiseFfi = initialiseFfi;
var libName = function (library, version) {
    var arch = ARCH_LOOKUP[process.arch];
    var platform = PLATFORM_LOOKUP[process.platform];
    if (!arch || !platform) {
        throw new Error("Pact does not currently support the operating system and architecture combination '" + process.platform + "/" + process.arch + "'");
    }
    var prefix = platform + "-" + arch;
    var extension = EXTENSION_LOOKUP[prefix];
    if (!extension) {
        throw new Error("Pact doesn't know what library to use for the architecture combination '" + process.platform + "/" + process.arch + "'");
    }
    return version + "-" + library + "-" + prefix + "." + extension;
};
exports.libName = libName;
//# sourceMappingURL=index.js.map