"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.verboseIsImplied = exports.setLogLevel = void 0;
var pino = require("pino");
var pkg = require('../package.json');
var DEFAULT_LEVEL = (process.env.LOGLEVEL || 'info');
var createLogger = function (level) {
    if (level === void 0) { level = DEFAULT_LEVEL; }
    var pinoLogger = pino({
        level: level.toLowerCase(),
        prettyPrint: {
            messageFormat: "pact-core@" + pkg.version + ": {msg}",
            translateTime: true,
        },
    });
    pinoLogger.pactCrash = function (message) {
        pinoLogger.error(pactCrashMessage(message));
    };
    return pinoLogger;
};
var pactCrashMessage = function (extraMessage) { return "!!!!!!!!! PACT CRASHED !!!!!!!!!\n\n" + extraMessage + "\n\nThis is almost certainly a bug in pact-js-core. It would be great if you could\nopen a bug report at: https://github.com/pact-foundation/pact-js-core/issues\nso that we can fix it.\n\nThere is additional debugging information above. If you open a bug report, \nplease rerun with logLevel: 'debug' set in the VerifierOptions, and include the\nfull output.\n\nSECURITY WARNING: Before including your log in the issue tracker, make sure you\nhave removed sensitive info such as login credentials and urls that you don't want\nto share with the world.\n\nLastly, we're sorry about this!\n"; };
var logger = createLogger();
var setLogLevel = function (wantedLevel) {
    if (wantedLevel) {
        logger.level =
            typeof wantedLevel === 'string'
                ? wantedLevel.toLowerCase()
                : logger.levels.labels[wantedLevel];
    }
    return logger.levels.values[logger.level];
};
exports.setLogLevel = setLogLevel;
var verboseIsImplied = function () {
    return logger.level === 'trace' || logger.level === 'debug';
};
exports.verboseIsImplied = verboseIsImplied;
exports.default = logger;
//# sourceMappingURL=logger.js.map